/*
 * mapblock.c -- ASCII text decoder made for Final Fantasy Tactics by
 *	Squaresoft.  This is not intended for copyright infringement.
 *
 * Copyright 2000, George Greer <greerga@muc.muohio.edu>
 *
 * Licensed under the GNU General Public License (GPL)
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *   or visit ftp://ftp.gnu.org/pub/gnu/COPYING via the Internet.
 */

#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#include "mmaplib.h"

static const char *copyright = "mapblock.c: Copyright 2000, George Greer <greerga@muc.muohio.edu>";
static const char *version = "v0.2 (Build: "__DATE__" "__TIME__")";

void mapblock(const unsigned char *data, size_t length, unsigned int block_len)
{
  size_t pos, iplace;

  for (pos = 0; pos < length; pos += block_len) {
#if 0
    for (iplace = 0; iplace < block_len; iplace++)
      putchar(data[pos + iplace]);
#else
    for (iplace = 0; iplace < block_len; iplace++)
      putchar(data[pos + iplace] >= 32 && data[pos + iplace] < 127 ? data[pos + iplace] : ' ' + (data[pos + iplace] % 95));
#endif
    putchar('\n');
  }
}

int main(int argc, char *argv[])
{
  int block_len;
  const char *filename;
  void *handle;

  if (argc > 1 && !strcmp(argv[1], "-V")) {
    printf("%s\n%s: version %s\n", copyright, argv[0], version);
    return 1;
  }

  if (argc < 3) {
    fprintf(stderr, "%s block-size map-to-parse\n\tor\n%s -V (for version and copyright)\n", argv[0], argv[0]);
    return 1;
  }

  block_len = atoi(argv[1]);
  filename = argv[2];

  if (!(handle = mapopen(filename)))
    error(filename);
  mapblock(mapdata(handle), maplength(handle), block_len);
  mapclose(handle);

  return 0;
}
